_internal_heap_flutter_autocapture library

Properties

globalHeapRedact bool
The global value to indicate whether the entire app should ignore interactions. This is useful when we need to apply a global ignore setting from the CSQ.start call.
getter/setter pair